histomicstk
============

This histomicstk package contains algorithms for fundamental image analysis
tasks including color normalization, color deconvolution, filtering to
enhance commonly found objects/structures, cell/nuclei segmentation, feature extraction, and tissue detection. It also contains algorithms and workflows to parse
annotations polygons into masks for training and validating algorithms
and vice versa.

.. toctree::
    :maxdepth: 2

    utils <histomicstk.utils>
    preprocessing <histomicstk.preprocessing>
    filters <histomicstk.filters>
    segmentation <histomicstk.segmentation>
    features <histomicstk.features>
    annotations and masks <histomicstk.annotations_and_masks>
    saliency (tissue/cellularity detection) <histomicstk.saliency>
    workflows <histomicstk.workflows>
